@@ -5,15 +5,16 @@ declare(strict_types=1);
 namespace Webmozart\Assert\Bin;
 
 use ArrayAccess;
-use Closure;
 use Countable;
 use ReflectionClass;
 use ReflectionException;
+use ReflectionIntersectionType;
 use ReflectionMethod;
+use ReflectionNamedType;
+use ReflectionType;
+use ReflectionUnionType;
 use RuntimeException;
-use Throwable;
 use Webmozart\Assert\Assert;
-use function rtrim;
 
 final class MixinGenerator
 {
@@ -22,7 +23,7 @@ final class MixinGenerator
      *
      * @var string[]
      */
-    private $unsupportedMethods = [
+    private array $unsupportedMethods = [
         'nullOrNotInstanceOf',  // not supported by psalm (https://github.com/vimeo/psalm/issues/3443)
         'allNotInstanceOf',     // not supported by psalm (https://github.com/vimeo/psalm/issues/3443)
         'nullOrNotEmpty',       // not supported by psalm (https://github.com/vimeo/psalm/issues/3443)
@@ -38,12 +39,16 @@ final class MixinGenerator
         'allIsNonEmptyMap',     // not supported by psalm (https://github.com/vimeo/psalm/issues/3444)
     ];
 
+    private array $skipGenerateForMethods = [
+        'isInitialized',
+    ];
+
     /**
      * @psalm-var list<string>
      *
      * @var string[]
      */
-    private $skipMethods = [
+    private array $skipMethods = [
         'nullOrNull',           // meaningless
         'nullOrNotNull',        // meaningless
         'allNullOrNull',        // meaningless
@@ -56,6 +61,8 @@ final class MixinGenerator
             <<<'PHP'
 <?php
 
+declare(strict_types=1);
+
 %s
 PHP
             ,
@@ -69,9 +76,7 @@ PHP
 
         $namespace = sprintf("namespace %s;\n\n", $assert->getNamespaceName());
         $namespace .= sprintf("use %s;\n", ArrayAccess::class);
-        $namespace .= sprintf("use %s;\n", Closure::class);
         $namespace .= sprintf("use %s;\n", Countable::class);
-        $namespace .= sprintf("use %s;\n", Throwable::class);
         $namespace .= "\n";
 
         $namespace .= $this->trait($assert);
@@ -115,7 +120,7 @@ trait Mixin
 
 PHP
             ,
-            implode("\n\n", $declaredMethods)
+            \implode("\n\n", $declaredMethods)
         );
     }
 
@@ -130,7 +135,11 @@ PHP
     private function nullOr(ReflectionMethod $method, int $indent): ?string
     {
         return $this->assertion($method, 'nullOr%s', '%s|null', $indent, function (string $firstParameter, string $parameters) use ($method) {
-            return "null === {$firstParameter} || static::{$method->name}({$firstParameter}, {$parameters});";
+            return <<<BODY
+null === {$firstParameter} || static::{$method->name}({$firstParameter}, {$parameters});
+
+return {$firstParameter};
+BODY;
         });
     }
 
@@ -151,6 +160,8 @@ static::isIterable({$firstParameter});
 foreach ({$firstParameter} as \$entry) {
     static::{$method->name}(\$entry, {$parameters});
 }
+
+return {$firstParameter};
 BODY;
         });
     }
@@ -172,6 +183,8 @@ static::isIterable({$firstParameter});
 foreach ({$firstParameter} as \$entry) {
     null === \$entry || static::{$method->name}(\$entry, {$parameters});
 }
+
+return {$firstParameter};
 BODY;
         });
     }
@@ -200,18 +213,34 @@ BODY;
         $parameters = [];
         /** @psalm-var array<string, scalar|null> $parametersDefaults */
         $parametersDefaults = [];
+        /** @var array<string, string> $parameterTypes */
+        $parameterTypes = [];
         $parametersReflection = $method->getParameters();
+        $nativeReturnType = 'mixed';
 
         foreach ($parametersReflection as $parameterReflection) {
             $parameters[] = $parameterReflection->name;
 
             if ($parameterReflection->isDefaultValueAvailable()) {
-                /** @var mixed $defaultValue */
                 $defaultValue = $parameterReflection->getDefaultValue();
-                Assert::nullOrScalar($defaultValue);
+                $defaultValue = Assert::nullOrScalar($defaultValue);
 
                 $parametersDefaults[$parameterReflection->name] = $defaultValue;
             }
+
+            if ($parameterReflection->hasType()) {
+                if ($parameterReflection->name === 'value') {
+                    $parameterTypes[$parameterReflection->name] = 'mixed';
+
+                    $nativeReturnType = match ($typeTemplate) {
+                        '%s|null' => $this->reduceParameterType($parameterReflection->getType()),
+                        'iterable<%s>' => 'iterable',
+                        'iterable<%s|null>' => 'iterable',
+                    };
+                } else {
+                    $parameterTypes[$parameterReflection->name] = $this->reduceParameterType($parameterReflection->getType());
+                }
+            }
         }
 
         if (in_array($newMethodName, $this->skipMethods, true)) {
@@ -220,6 +249,8 @@ BODY;
 
         $paramsAdded = false;
 
+        $phpdocReturnType = 'mixed';
+
         $phpdocLines = [];
         foreach ($parsedComment as $key => $values) {
             if ($this->shouldSkipAnnotation($newMethodName, $key)) {
@@ -242,13 +273,17 @@ BODY;
 
             foreach ($values as $i => $value) {
                 $parts = $this->splitDocLine($value);
-                if (('param' === $key || 'psalm-param' === $key) && isset($parts[1]) && $parts[1] === '$'.$parameters[0] && 'mixed' !== $parts[0]) {
+                if (('param' === $key || 'psalm-param' === $key) && isset($parts[1]) && isset($parameters[0]) && $parts[1] === '$'.$parameters[0] && 'mixed' !== $parts[0]) {
                     $parts[0] = $this->applyTypeTemplate($parts[0], $typeTemplate);
 
-                    $values[$i] = implode(' ', $parts);
+                    $values[$i] = \implode(' ', $parts);
                 }
             }
 
+            if ('psalm-return' === $key || 'return' === $key) {
+                continue;
+            }
+
             if ('param' === $key) {
                 [$longestType, $longestName] = $this->findLongestTypeAndName($values);
             }
@@ -259,10 +294,12 @@ BODY;
 
                 if ('psalm-assert' === $key) {
                     $type = $this->applyTypeTemplate($type, $typeTemplate);
+
+                    $phpdocReturnType = $type;
                 }
 
                 if ('param' === $key) {
-                    if (!array_key_exists(1, $parts)) {
+                    if (!isset($parts[1])) {
                         throw new RuntimeException(sprintf('param key must come with type and variable name in method: %s', $method->name));
                     }
 
@@ -272,17 +309,20 @@ BODY;
 
                 $comment = sprintf('@%s %s', $key, $type);
                 if (count($parts) >= 2) {
-                    $comment .= sprintf(' %s', implode(' ', array_slice($parts, 1)));
+                    $comment .= sprintf(' %s', \implode(' ', array_slice($parts, 1)));
                 }
 
                 $phpdocLines[] = trim($comment);
             }
 
-            if ('deprecated' === $key || 'psalm-pure' === $key) {
+            if ('deprecated' === $key || 'psalm-pure' === $key || 'psalm-assert' === $key || 'see' === $key) {
                 $phpdocLines[] = '';
             }
         }
 
+        $phpdocLines[] = '@return '.$phpdocReturnType;
+        $phpdocLines[] = '';
+
         $phpdocLinesDeduplicatedEmptyLines = [];
         foreach ($phpdocLines as $line) {
             $currentLine = trim($line);
@@ -296,7 +336,26 @@ BODY;
             $phpdocLinesDeduplicatedEmptyLines[] = $line;
         }
 
-        return $this->staticMethod($newMethodName, $parameters, $parametersDefaults, $phpdocLinesDeduplicatedEmptyLines, $indent, $body);
+        return $this->staticMethod($newMethodName, $parameters, $parameterTypes, $parametersDefaults, $phpdocLinesDeduplicatedEmptyLines, $indent, $body, $nativeReturnType);
+    }
+
+    private function reduceParameterType(ReflectionType $type): string
+    {
+        if ($type instanceof ReflectionIntersectionType) {
+            return \implode('&', \array_map([$this, 'reduceParameterType'], $type->getTypes()));
+        }
+
+        if ($type instanceof ReflectionUnionType) {
+            return \implode('|', \array_map([$this, 'reduceParameterType'], $type->getTypes()));
+        }
+
+        $type = Assert::isInstanceOf($type, ReflectionNamedType::class);
+
+        if ($type->getName() === 'mixed') {
+            return $type->getName();
+        }
+
+        return ($type->allowsNull() ? '?' : '') . $type->getName();
     }
 
     private function applyTypeTemplate(string $type, string $typeTemplate): string
@@ -316,7 +375,7 @@ BODY;
             return false;
         }
 
-        return 'psalm-assert' === $key;
+        return 'psalm-assert' === $key || 'psalm-return' === $key;
     }
 
     /**
@@ -339,7 +398,7 @@ BODY;
                 $longestType = strlen($type);
             }
 
-            if (!array_key_exists(1, $parts)) {
+            if (!isset($parts[1])) {
                 continue;
             }
 
@@ -353,49 +412,54 @@ BODY;
     }
 
     /**
-     * @psalm-param list<string> $parameters
-     * @psalm-param array<string, scalar|null> $defaultValues
-     * @psalm-param list<string> $phpdocLines
-     * @psalm-param callable(string,string):string $body
+     * @psalm-param list<string>                   $parameters
+     * @psalm-param array<string, scalar|null>     $defaults
+     * @psalm-param list<string>                   $phpdocLines
      *
-     * @param string   $name
-     * @param string[] $parameters
-     * @param string[] $defaultValues
-     * @param array    $phpdocLines
-     * @param int      $indent
-     * @param callable $body
+     * @param string                               $name
+     * @param string[]                             $parameters
+     * @param array<string, string>                $types
+     * @param string[]                             $defaults
+     * @param array                                $phpdocLines
+     * @param int                                  $indent
+     * @param callable(string,string): string      $body
+     * @param string                               $returnType
      *
      * @return string
      */
-    private function staticMethod(string $name, array $parameters, array $defaultValues, array $phpdocLines, int $indent, callable $body): string
+    private function staticMethod(string $name, array $parameters, array $types, array $defaults, array $phpdocLines, int $indent, callable $body, string $returnType): string
     {
+        Assert::notEmpty($parameters);
+
         $indentation = str_repeat(' ', $indent);
 
+        $parameterList = \array_map(static fn (string $parameter): string => '$'.$parameter, $parameters);
+        $firstParameter = \array_shift($parameterList);
+        $parameterList = \implode(', ', $parameterList);
+
+        $methodBody = \preg_replace('/(?<=^|\n)(?!\n)/', $indentation.$indentation, $body($firstParameter, $parameterList));
+
+        Assert::stringNotEmpty($methodBody);
+
         $staticFunction = $this->phpdoc($phpdocLines, $indent)."\n";
-        $staticFunction .= $indentation.'public static function '.$name.$this->functionParameters($parameters, $defaultValues)."\n"
+        $staticFunction .= $indentation.'public static function '.$name.$this->functionParameters($parameters, $types, $defaults).": {$returnType}\n"
             .$indentation."{\n";
-
-        $firstParameter = '$'.array_shift($parameters);
-        $parameters = implode(', ', \array_map(static function (string $parameter): string {
-            return '$'.$parameter;
-        }, $parameters));
-
-        $staticFunction .= preg_replace('/(?<=^|\n)(?!\n)/', $indentation.$indentation, $body($firstParameter, $parameters))."\n";
-        $staticFunction .= $indentation.'}';
+        $staticFunction .= $methodBody."\n".$indentation."}";
 
         return $staticFunction;
     }
 
     /**
-     * @psalm-param list<string> $parameters
-     * @psalm-param array<string, scalar|null> $defaultValues
+     * @psalm-param list<string>               $parameters
+     * @psalm-param array<string, scalar|null> $defaults
      *
-     * @param string[] $parameters
-     * @param string[] $defaultValues
+     * @param string[]                         $parameters
+     * @param array<string, string>            $types
+     * @param string[]                         $defaults
      *
      * @return string
      */
-    private function functionParameters(array $parameters, array $defaultValues): string
+    private function functionParameters(array $parameters, array $types, array $defaults): string
     {
         $result = '';
 
@@ -404,10 +468,12 @@ BODY;
                 $result .= ', ';
             }
 
-            $result .= '$'.$parameter;
+            Assert::keyExists($types, $parameter);
 
-            if (array_key_exists($parameter, $defaultValues)) {
-                $defaultValue = null === $defaultValues[$parameter] ? 'null' : var_export($defaultValues[$parameter], true);
+            $result .= $types[$parameter].' $'.$parameter;
+
+            if (array_key_exists($parameter, $defaults)) {
+                $defaultValue = null === $defaults[$parameter] ? 'null' : var_export($defaults[$parameter], true);
 
                 $result .= ' = '.$defaultValue;
             }
@@ -432,10 +498,10 @@ BODY;
         $throws = '';
 
         foreach ($lines as $line) {
-            if (strpos($line, '@throws') === 0) {
-                $throws .= "\n".$indentation.rtrim(' * '.$line);
+            if (\str_starts_with($line, '@throws')) {
+                $throws .= "\n".$indentation.\rtrim(' * '.$line);
             } else {
-                $phpdoc .= "\n".$indentation.rtrim(' * '.$line);
+                $phpdoc .= "\n".$indentation.\rtrim(' * '.$line);
             }
         }
 
@@ -474,7 +540,7 @@ BODY;
     }
 
     /**
-     * @psalm-return array{0: string, 1?: string, 2?: string}
+     * @psalm-return list{string, string|null, string|null}
      *
      * @param string $line
      *
@@ -483,15 +549,10 @@ BODY;
     private function splitDocLine(string $line): array
     {
         if (!preg_match('~^(.*)\s+(\$\S+)(?:\s+(.*))?$~', $line, $matches)) {
-            return [$line];
+            return [$line, null, null];
         }
 
-        $parts = [trim($matches[1]), $matches[2]];
-        if (count($matches) > 3) {
-            $parts[2] = $matches[3];
-        }
-
-        return $parts;
+        return [trim($matches[1]), $matches[2], $matches[3] ?? null];
     }
 
     /**
@@ -508,6 +569,10 @@ BODY;
         $staticMethods = $assert->getMethods(ReflectionMethod::IS_STATIC);
 
         foreach ($staticMethods as $staticMethod) {
+            if (in_array($staticMethod->name, $this->skipGenerateForMethods)) {
+                continue;
+            }
+
             $modifiers = $staticMethod->getModifiers();
             if (0 === ($modifiers & ReflectionMethod::IS_PUBLIC)) {
                 continue;
