@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -9,10 +11,8 @@ use Webmozart\Assert\Assert;
  *
  * @param object|string $value
  * @param array<class-string> $classes
- *
- * @return object|string
  */
-function isAnyOf($value, array $classes)
+function isAnyOf($value, array $classes): object|string
 {
     Assert::isAnyOf($value, $classes);
 
@@ -24,10 +24,8 @@ function isAnyOf($value, array $classes)
  *
  * @param null|object|string $value
  * @param array<class-string> $classes
- *
- * @return null|object|string
  */
-function nullOrIsAnyOf($value, array $classes)
+function nullOrIsAnyOf($value, array $classes): object|string|null
 {
     Assert::nullOrIsAnyOf($value, $classes);
 
@@ -39,8 +37,6 @@ function nullOrIsAnyOf($value, array $classes)
  *
  * @param iterable<object|string> $value
  * @param array<class-string> $classes
- *
- * @return iterable<object|string>
  */
 function allIsAnyOf($value, array $classes): iterable
 {
@@ -54,8 +50,6 @@ function allIsAnyOf($value, array $classes): iterable
  *
  * @param iterable<object|string|null> $value
  * @param array<class-string> $classes
- *
- * @return iterable<object|string|null>
  */
 function allNullOrIsAnyOf($value, array $classes): iterable
 {
