@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -32,8 +34,6 @@ function nullOrLower(?string $value): ?string
  * @psalm-pure
  *
  * @param iterable<string> $value
- *
- * @return iterable<lowercase-string>
  */
 function allLower(iterable $value): iterable
 {
@@ -46,8 +46,6 @@ function allLower(iterable $value): iterable
  * @psalm-pure
  *
  * @param iterable<string|null> $value
- *
- * @return iterable<lowercase-string|null>
  */
 function allNullOrLower(iterable $value): iterable
 {
