@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -28,8 +30,6 @@ function nullOrRegex(?string $value, string $pattern): ?string
  * @psalm-pure
  *
  * @param iterable<string> $value
- *
- * @return iterable<string>
  */
 function allRegex(iterable $value, string $pattern): iterable
 {
@@ -42,8 +42,6 @@ function allRegex(iterable $value, string $pattern): iterable
  * @psalm-pure
  *
  * @param iterable<string|null> $value
- *
- * @return iterable<string|null>
  */
 function allNullOrRegex(iterable $value, string $pattern): iterable
 {
