@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -9,10 +11,8 @@ use Webmozart\Assert\Assert;
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function same($value, $expect)
+function same($value, $expect): mixed
 {
     Assert::same($value, $expect);
 
@@ -24,10 +24,8 @@ function same($value, $expect)
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function nullOrSame($value, $expect)
+function nullOrSame($value, $expect): mixed
 {
     Assert::nullOrSame($value, $expect);
 
@@ -39,10 +37,8 @@ function nullOrSame($value, $expect)
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function allSame($value, $expect)
+function allSame($value, $expect): mixed
 {
     Assert::allSame($value, $expect);
 
@@ -54,10 +50,8 @@ function allSame($value, $expect)
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function allNullOrSame($value, $expect)
+function allNullOrSame($value, $expect): mixed
 {
     Assert::allNullOrSame($value, $expect);
 
